@@ -61,18 +61,14 @@ static struct Mode *modePtr;
 
 int gnome_mode;
 
-#ifdef LOCALE
-#include <locale.h>
-#endif
-
 int main(int argc, char *argv[])
 {
 	int offset = 0, clear_screen = 0, end_common_opts = 0, retval;
 	const char *title = NULL;
 
-#ifdef LOCALE
-	(void) setlocale(LC_ALL, "");
-#endif
+	bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+	textdomain(GETTEXT_PACKAGE);
 
 	if (argc < 2) {
 		Usage(argv[0]);
@@ -81,9 +77,7 @@ int main(int argc, char *argv[])
 	
 	if(getenv("DISPLAY"))
 	{
-		gtk_init(&argc, &argv);
-		gdk_imlib_init();
-		gnomelib_init(argv[0], VERSION);
+		gnome_init("gdialog", VERSION, argc, argv);
 		gnome_mode=1;
 	}
 	
