@@ -1,4 +1,4 @@
-/* $Id: gdict-applet.c,v 1.15.2.1 2001/10/03 03:38:06 jfleck Exp $ */
+/* $Id: gdict-applet.c,v 1.19 2001/12/06 23:49:53 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -19,7 +19,12 @@
 #include <assert.h>
 
 #include <gnome.h>
-#include <applet-widget.h>
+#ifdef GDICT_APPLET_WORKS
+  #include <applet-widget.h>
+#endif
+
+#include <libbonoboui.h>
+#include <panel-applet.h>
 
 #include "gdict-app.h"
 #include "gdict-about.h"
@@ -27,18 +32,20 @@
 #include "gdict-applet.h"
 #include "gdict-pref-dialog.h"
 
-gboolean gdict_applet_toggle = TRUE;
+
 
 #define DOCKED_APPLET_WIDTH 74
 #define FLOATING_APPLET_WIDTH 14
 #define SHORT_APPLET_HEIGHT 22
 #define TALL_APPLET_HEIGHT 44
 
+#ifdef GDICT_APPLET_WORKS
 /* Returns the ideal vertical applet size based on panel width and
  * orientation. */
 static gint 
 gdict_applet_determine_height(GDictApplet *applet)
 {
+
 	int ideal_panel_size = 0;
 	PanelOrientType orientation = ORIENT_UP;
 
@@ -53,6 +60,8 @@ gdict_applet_determine_height(GDictApplet *applet)
 		return SHORT_APPLET_HEIGHT;
 	else
 		return TALL_APPLET_HEIGHT;
+
+	return 0;
 }
 
 /* Returns the ideal horizontal applet size based on panel width and
@@ -60,12 +69,15 @@ gdict_applet_determine_height(GDictApplet *applet)
 static gint
 gdict_applet_determine_width(GDictApplet *applet)
 {
+
 	if (applet->handlebox_widget != NULL && 
 		GTK_HANDLE_BOX(applet->handlebox_widget)->child_detached)
 
 		return FLOATING_APPLET_WIDTH;
 	else
 		return DOCKED_APPLET_WIDTH;
+
+	return 0;
 }
 
 /* Configures and displays the applet as appropriate for the panel
@@ -73,6 +85,7 @@ gdict_applet_determine_width(GDictApplet *applet)
 static void
 gdict_applet_render (GDictApplet * applet)
 {
+
 	gint applet_height = 0;
 	gint applet_width = 0;
 
@@ -101,6 +114,7 @@ gdict_applet_render (GDictApplet * applet)
 		gtk_widget_set_usize(applet->vbox_widget, applet_width, applet_height);
 	}
 	gtk_widget_show (applet->applet_widget);
+
 }
 
 /* Signal handler that gets called when the user re-attaches the
@@ -162,15 +176,7 @@ cb_help (GtkWidget *w, gpointer data)
 	gnome_help_display(NULL, &help_entry);
 }
 
-/* Signal handler for the "Show/Hide Definition Window" menu item */
-static void
-applet_show_hide_defbox_cb (AppletWidget *widget, gpointer data) 
-{
-    if (!GTK_WIDGET_VISIBLE (gdict_app))
-        gtk_widget_show (gdict_app);
-    else
-        gtk_widget_hide (gdict_app);
-}
+
 
 /* Signal handler for "Spell Check" menu item */
 static void
@@ -184,29 +190,6 @@ applet_spell_cb (AppletWidget *widget, gpointer data)
     gtk_entry_set_text (GTK_ENTRY (applet->entry_widget), "");
 }
 
-/* Signal handler to process mouse clicks on the applet */
-static void
-applet_clicked_cb (GtkWidget *widget, GdkEventButton *ev, gpointer data)
-{
-    if ((ev == NULL) || (ev->button != 1) || (ev->type != GDK_2BUTTON_PRESS ))
-        return;
-
-    applet_show_hide_defbox_cb (APPLET_WIDGET (widget), data);
-}
-
-/* Signal handler for the "About" menu item */
-static void
-applet_about_cb (AppletWidget *widget, gpointer data)
-{
-    gdict_about();
-}
-
-/* Signal handler for the "Preferences" menu item */
-static void
-applet_pref_cb (AppletWidget *widget, gpointer data) 
-{
-    gdict_app_show_preferences ();
-}
 
 /* Signal handler for any event that should trigger a lookup */
 static void
@@ -226,15 +209,6 @@ applet_lookup_cb (GtkWidget *widget, gpointer data)
     gdict_app_do_lookup (text);
 }
 
-/* Establishes explicit associations between wigets and events that
- * aren't enabled by default. */
-static void 
-gdict_applet_set_events (GDictApplet * applet)
-{
-    gtk_widget_set_events (applet->applet_widget, 
-						   gtk_widget_get_events(applet->applet_widget) |
-                           GDK_BUTTON_PRESS_MASK | GDK_EXPOSURE_MASK );
-}
 
 /* Connects any signal handlers needed for the applet to function. */
 static void
@@ -297,6 +271,7 @@ gdict_applet_populate_menu (GDictApplet * applet)
 		 _("Spell Check..."), applet_spell_cb, (gpointer) applet);
 }
 
+
 /* Constructs an applet object, containing all its necessary widgets */
 static GDictApplet * 
 gdict_applet_new ()
@@ -310,7 +285,7 @@ gdict_applet_new ()
 
     applet->vbox_widget = gtk_vbox_new(FALSE, 2);
     applet->entry_widget = gtk_entry_new();
-    applet->button_widget = gtk_button_new_with_label(_("Look up"));
+    applet->button_widget = gtk_button_new_with_label(_("Lookup"));
 
     applet->handle = gdict_pref.applet_handle;
 
@@ -326,13 +301,7 @@ gdict_applet_new ()
 	return applet;
 }
 
-/* Deletes the GDictApplet structure returned by gdict_applet_new */
-void gdict_applet_delete (GDictApplet * applet)
-{
-	g_return_if_fail (applet);
-	/* Can I safely assume that GTK will clean up my widgets for me? */
-	g_free (applet);
-}
+
 
 /* Packs and adds widgets inside container widgets, as needed for the
  * applet.  When this call is finished, the interface for the applet
@@ -360,26 +329,191 @@ gdict_applet_pack_widgets (GDictApplet * applet)
 					 TRUE, 0);
 }
 
-/* Creates and displays the applet.  Returns a structure containing
- * the state of the applet.  After applet_widget_gtk_main exits, this
- * structure may be safely deleted using gdict_applet_delete */
-GDictApplet * gdict_applet_create (void)
-{
-	GDictApplet *applet = NULL;
 
-#if 0
-    GtkWidget *frame_in, *frame_out;
+
 #endif
 
-    g_assert(gdict_applet_toggle);
-
-	applet = gdict_applet_new();
-
-	gdict_applet_set_events (applet);
-	gdict_applet_connect_signals (applet);
-	gdict_applet_populate_menu (applet);
-	gdict_applet_pack_widgets (applet);
-	gdict_applet_render (applet);
-
-	return applet;
+static void
+entry_activate_cb (GtkEntry *entry, gpointer data)
+{
+    gchar *text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+    
+    if (!context)
+		gdict_init_context ();
+    if (!GTK_WIDGET_VISIBLE (gdict_app))
+        gtk_widget_show (gdict_app);
+    
+    if (*text == 0)
+        return;
+    g_strdown (text);
+    gdict_app_do_lookup (text);
+    gtk_entry_set_text (GTK_ENTRY (word_entry), text);
+    g_free (text);
+ 
+#if 0   
+    gtk_entry_set_text (GTK_ENTRY (applet->entry_widget), "");
+    gtk_entry_set_text (GTK_ENTRY (word_entry), text);
+    gtk_editable_select_region (GTK_EDITABLE (word_entry), 0, strlen (text));
+    gdict_app_do_lookup (text);
+#endif
 }
+
+static void
+text_received (GtkClipboard *clipboard, const gchar *text, gpointer data)
+{
+	GtkEntry *entry = GTK_ENTRY (data);	
+	
+	if (!text)
+		return;
+		
+	g_print ("text = %s \n", text);
+			
+	gtk_entry_set_text (entry, text);
+	entry_activate_cb (entry, NULL);
+	
+}
+
+static void
+button_press_cb (GtkButton *button, gpointer data)
+{
+	GtkEntry *entry = GTK_ENTRY (data);
+	GtkClipboard *clipboard;
+	
+	clipboard = gtk_clipboard_get (GDK_SELECTION_PRIMARY);
+ 		
+ 	gtk_clipboard_request_text (clipboard, text_received, entry);
+	
+	/*entry_activate_cb (entry, NULL);*/
+	
+}
+
+static void
+about_cb (BonoboUIComponent *uic,
+          gpointer           user_data,
+          const gchar       *verbname)
+{
+	gdict_about();
+}
+
+static void
+help_cb (BonoboUIComponent *uic,
+          gpointer           user_data,
+          const gchar       *verbname)
+{
+
+}
+
+static void
+prefs_cb (BonoboUIComponent *uic,
+          gpointer           user_data,
+          const gchar       *verbname)
+{
+	gdict_app_show_preferences ();
+}
+
+static void
+show_hide_defbox_cb (BonoboUIComponent *uic,
+          gpointer           user_data,
+          const gchar       *verbname)
+{
+	if (!context)
+		gdict_init_context ();
+	if (!GTK_WIDGET_VISIBLE (gdict_app))
+        	gtk_widget_show (gdict_app);
+    	else
+        	gtk_widget_hide (gdict_app);
+}
+
+static void
+spell_cb (BonoboUIComponent *uic,
+          gpointer           user_data,
+          const gchar       *verbname)
+{
+	if (!context)
+		gdict_init_context ();
+#ifdef FIXME
+	GtkWidget *entry = GTK_WIDGET (user_data);
+	text = gtk_entry_get_text (GTK_ENTRY (applet->entry_widget));
+    	gdict_spell (text, FALSE);
+    gtk_entry_set_text (GTK_ENTRY (applet->entry_widget), "");
+#endif
+}
+
+static const BonoboUIVerb gdict_applet_menu_verbs [] = {
+        BONOBO_UI_VERB ("about", about_cb),
+        BONOBO_UI_VERB ("help", help_cb),
+        BONOBO_UI_VERB ("prefs", prefs_cb),
+	BONOBO_UI_VERB ("def win", show_hide_defbox_cb),
+        BONOBO_UI_VERB ("spell", spell_cb),
+
+        BONOBO_UI_VERB_END
+};
+
+static const char gdict_applet_menu_xml [] =
+        "<popup name=\"button3\">\n"
+        "   <menuitem name=\"Item 1\" verb=\"about\" _label=\"About...\"/>\n"
+        "   <menuitem name=\"Item 2\" verb=\"help\" _label=\"Help\"/>\n"
+        "   <menuitem name=\"Item 3\" verb=\"prefs\" _label=\"Preferences...\"/>\n"
+        "   <menuitem name=\"Item 4\" verb=\"def win\" _label=\"Show/Hide Definition Window...\"/>\n"
+        "   <menuitem name=\"Item 5\" verb=\"spell\" _label=\"Spell Check...\"/>\n"
+        "</popup>\n";
+
+static BonoboObject *
+gdict_applet_new (void) {
+ 	GtkWidget *applet;
+ 	GtkWidget *hbox;
+ 	GtkWidget *button; 	 	
+ 	GtkWidget *entry;
+ 	
+	hbox = gtk_hbox_new (FALSE, 0);
+	
+	button = gtk_button_new_with_label (_("Lookup"));
+	gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 2);
+	  	
+ 	entry = gtk_entry_new ();
+ 	gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 0);
+ 	
+ 	applet = panel_applet_new (hbox);
+ 	
+ 	gdict_app_create (TRUE);
+ 	
+ 	panel_applet_setup_menu (PANEL_APPLET (applet),
+                                 gdict_applet_menu_xml,
+                                 gdict_applet_menu_verbs,
+                                 NULL);                               
+                                 
+ 	gtk_widget_show_all (applet);
+ 	gdict_pref_load ();
+ 	
+ 	/* server will be contacted when an action is performed */
+ 	context = NULL;
+ 	
+ 	g_signal_connect (G_OBJECT (entry), "activate",
+ 			  G_CALLBACK (entry_activate_cb), NULL);
+ 	g_signal_connect (G_OBJECT (button), "clicked",
+ 			  G_CALLBACK (button_press_cb), entry);
+ 	
+ 	
+ 	return BONOBO_OBJECT (panel_applet_get_control (PANEL_APPLET (applet)));
+ 	
+}
+
+static BonoboObject *
+gdict_applet_factory (BonoboGenericFactory *this,
+                     const gchar          *iid,
+                     gpointer              data)
+{
+        BonoboObject *applet = NULL;
+
+        if (!strcmp (iid, "OAFIID:GNOME_GDictApplet"))
+                applet = gdict_applet_new ();
+
+        return applet;
+}
+
+PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_GDictApplet_Factory",
+                             "Dictionary",
+                             "0",
+                             gdict_applet_factory,
+                             NULL)
+ 	
