@@ -1,7 +1,7 @@
 #ifndef __GDICT_APPLET_H_
 #define __GDICT_APPLET_H_
 
-/* $Id: gdict-applet.h,v 1.3 2000/12/22 16:36:32 hovinen Exp $ */
+/* $Id: gdict-applet.h,v 1.5 2001/12/05 03:30:18 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim@cs.cmu.edu>
@@ -22,12 +22,9 @@ typedef struct _GDictApplet {
 	GtkWidget *vbox_widget;
 	GtkWidget *entry_widget;
 	GtkWidget *handlebox_widget;
+	gboolean handle;
 } GDictApplet;
 
-extern gboolean gdict_applet_toggle;
-
-extern GDictApplet * gdict_applet_create (void);
-extern void gdict_applet_delete (GDictApplet * applet);
 
 
 #endif /* __GDICT_APPLET_H_ */
